@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, Union
 
 import abjad
 
@@ -311,7 +311,7 @@ class LeafDynMaker(abjad.LeafMaker):
 
     ### INITIALISER ###
 
-    def __init__(self):
+    def __init__(self) -> None:
         r'Initialises self.'
         super().__init__()
 
@@ -385,11 +385,18 @@ class LeafDynMaker(abjad.LeafMaker):
     ### PRIVATE METHODS ###
 
     def _add_dynamics_and_articulations(self,
-                                        logical_ties,
-                                        dynamics_,
-                                        articulations_,
-                                        omit_repeated_dynamics,
-                                        ):
+                                        logical_ties: list[abjad.LogicalTie],
+                                        dynamics_: list[Union[str,
+                                                              abjad.Dynamic,
+                                                              ]],
+                                        articulations_: list[Union[
+                                            str,
+                                            abjad.Articulation,
+                                            abjad.Staccatissimo,
+                                            abjad.Staccato,
+                                        ]],
+                                        omit_repeated_dynamics: bool,
+                                        ) -> None:
         r'Adds dynamics and articulations to logical ties.'
         previous_dynamic = None
         for logical_tie, dynamic, articulation in zip(logical_ties,
@@ -408,7 +415,7 @@ class LeafDynMaker(abjad.LeafMaker):
                     abjad.attach(articulation, logical_tie.head)
 
     @staticmethod
-    def _listify(argument) -> list:
+    def _listify(argument) -> list[Any]:
         r'Returns a :obj:`list` if argument is not a :obj:`list`.'
         if argument:
             if isinstance(argument, list):
@@ -419,10 +426,12 @@ class LeafDynMaker(abjad.LeafMaker):
             return []
 
     @staticmethod
-    def _fill_list(input_list,
+    def _fill_list(input_list: list[Any],
                    length: int,
+                   *,
                    cyclic: bool = False,
-                   default: Any = None):
+                   default: Any = None,
+                   ) -> None:
         r"""Extends a :obj:`list` to a certain length, filling it with a
         default value. If ``cyclic`` is ``True``, then it fills the :obj:`list`
         by cycling the original ``input_list``.
