@@ -1,5 +1,5 @@
-import collections
-from typing import Iterable, Union
+from collections.abc import Iterable
+from typing import Union
 
 import abjad
 
@@ -41,16 +41,15 @@ class Inspection:
     def __init__(self,
                  client: Union[abjad.Component,
                                Iterable[abjad.Component],
+                               None,
                                ] = None,
-                 ):
+                 ) -> None:
         r'Initialises self.'
         assert not isinstance(client, str), repr(client)
-        if not isinstance(client, (abjad.Component,
-                                   collections.abc.Iterable,
-                                   type(None),
-                                   )):
-            raise TypeError('must be component, non-string iterable or None: '
-                            f'(not {client!r}).')
+        if not isinstance(client, (abjad.Component, Iterable, None)):
+            raise TypeError("must be 'abjad.Component', iterable of "
+                            "'abjad.Component's, or None: "
+                            f"(not {client!r}).")
         self._client = client
 
     ### SPECIAL METHODS ###
@@ -66,7 +65,7 @@ class Inspection:
                                 do_not_use_none: bool = False,
                                 implicit_common_time: bool = True,
                                 omit_repeated: bool = False,
-                                ) -> list:
+                                ) -> list[abjad.TimeSignature]:
         return extract_time_signatures(
             self._client,
             do_not_use_none=do_not_use_none,
@@ -113,7 +112,11 @@ Inspection.underfull_duration.__doc__ = underfull_duration.__doc__
 
 ### FUNCTIONS ###
 
-def inspect(client):
+def inspect(client: Union[abjad.Component,
+                          Iterable[abjad.Component],
+                          None,
+                          ] = None,
+            ) -> Inspection:
     r"""Makes an inspection agent. See :class:`Inspection` for the
     documentation of all of its methods.
 
