@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Union
 
 import abjad
 
@@ -15,7 +15,9 @@ from .prettify_rewrite_meter import (
 
 
 def auto_rewrite_meter(container: abjad.Container,
-                       meter_list: list = None,
+                       meter_list: Optional[list[Union[abjad.Meter,
+                                                       abjad.TimeSignature,
+                                                       ]]] = None,
                        *,
                        prettify_rewrite_meter: bool = True,
                        extract_trivial_tuplets: bool = True,
@@ -27,7 +29,7 @@ def auto_rewrite_meter(container: abjad.Container,
                        rewrite_tuplets: bool = True,
                        merge_partial_tuplets: bool = True,
                        split_quadruple_meter: bool = True,
-                       ):
+                       ) -> None:
     r"""Mutates an input container (of type |abjad.Container| or child class)
     in place and has no return value; this function takes every measure of a
     container, detects its time signature, and apply both
@@ -582,12 +584,10 @@ def auto_rewrite_meter(container: abjad.Container,
     if not isinstance(split_quadruple_meter, bool):
         raise TypeError("'split_quadruple_meter' must be 'bool'")
 
-    if extract_trivial_tuplets:
-        extract_trivial_tuplets_function(container[:])
     if merge_partial_tuplets:
         merge_partial_tuplets_function(container[:])
-        if extract_trivial_tuplets:
-            extract_trivial_tuplets_function(abjad.select(container))
+    if extract_trivial_tuplets:
+        extract_trivial_tuplets_function(container[:])
 
     if meter_list is None:
         time_signatures = inspect(container).extract_time_signatures(
@@ -596,6 +596,8 @@ def auto_rewrite_meter(container: abjad.Container,
         meter_list = [abjad.Meter(ts.pair) for ts in time_signatures]
     measures = abjad.select(container[:]).group_by_measure()
     for meter, measure in zip(meter_list, measures):
+        if isinstance(measure[0], abjad.MultimeasureRest):
+            continue
         abjad.mutate(measure).rewrite_meter(
             meter,
             boundary_depth=boundary_depth,
